#' R script to accompany the manuscript, "Littorally adaptive? Testing the link between 
#' habitat, morphology, and reproduction in the intertidal sculpin subfamily 
#' Oligocottinae (Pisces: Cottoidea)" by T.J. Buser, M.D. Burns and J.A. Lopez. 
#' Submitted to PeerJ in January 2017. 
#' 
#' Corresponding author: T.J. Buser    
#' email: BuserT@OregonState.edu

# Be sure to set your working drive
setwd("
  //LitorallyAdaptive_PeerJ_Rfolder")     



library(phytools)
library(ape)
library(geiger)
library(nlme)
library(ggplot2)
library(vegan)
library(phylolm)
#dev.off()

#' This script is organized to match the order of the Materials and Methods section.
#' 
#### Organization of script #######
#'
#' Phylogenetic framework:   Lines 040 - 058
#' Character coding- Depth Range: Lines 059 - 142
#' Character mapping and ancestral state reconstruction: Lines 143 - 246
#' Body shape analysis: Lines 247 - 284
#' Depth correlation analysis: Lines 285 - 419
#' 
#' 
#' 
#' 
#' 
#' 
#' 
################## Phylogenetic Framework #################

#' Read in MCC phylogeny inferred from Buser and Lopez (2015) molecular dataset.
#' This phylogeny contains all species of the subfamily Oligocottinae as well as 
#' several outgroup taxa. 
sculpin.tree <- read.nexus(file = "sculpin_birthdeath_mcc_starbeast.tree")
print(sculpin.tree)
plotTree(sculpin.tree)
nodelabels()

#' For the purposes of analysis, we will extract the clade containing Oligocottinae 
#' and the outgroup taxon Chitonotus pugetensis
Oligo_tree <- extract.clade(sculpin.tree, 52)
plotTree(Oligo_tree) #Verify
nodelabels()
#'
#'
#'
#'
####################### Character coding- Depth Range ################
#'
#'
#'
#'
#'
############### Import data matrix
#'
# Import data matrix, see below description of columns and binary character states
Oligo_data <- read.csv(file = "LitorallyAdaptive_datamatrix.csv", header = T, row.names = 1)
#'
#'
#' Species values for each PC axis are found in columns "PC1"-"PC16" [,1:16].
#' Description of remaining columns:
#' [,17], "Lit.MaxDepth.m": maximum depth in meters for each species, taken from literature. Values 
#' are synthesized from a review of field guides and primary literature, see Methods
#' for full description.
#' [,18], "Lit.MinDepth.m": minimum depth in meters for each species, taken from literature. Values 
#' are synthesized from a review of field guides and primary literature, see Methods
#' for full description. 
#' [,19], "Max_Length.mm": maximum length in millimeters reported for each species. Values 
#' are synthesized from a review of field guides and primary literature, see Methods
#' for full description.
#' [,20], "Papilla": Absence (0) or Presence (1) of genital papilla in oligocottine
#' species. Values are taken from a review of primary literature, see 
#' Methods for full description.
#' [,21], "Squamation": Absence (0) or Presence (1) of scales or scale-like structures
#' outside of the lateral line in oligocottine species. Values are taken from a review 
#' of primary literature, see Methods for full description.
#' [,22], "Squamation2": Scales absent outside of lateral line (0), plate-like scales 
#' present (1), or prickle-like scales present in oligocottine species. Values are taken 
#' from a review of primary literature, see Methods for full description.
#' [,23], "Mus95.MaxDepth": maximum depth in meters for each species, taken from museum data.
#' Values are from a depth range that contains 95% of collection depths reported for 
#' individuals of each species in museum holdings. See Methods and for full description.
#' [,24], "Mus95.MinDepth": minimum depth in meters for each species, taken from museum data.
#' Values are from a depth range that contains 95% of collection depths reported for 
#' individuals of each species in museum holdings. See Methods and for full description.
#
#make sure the names match between the phylogeny and data matrix
name.check(Oligo_tree, Oligo_data) #looks good
#'
#'
################## Depth classifications
dev.off()
#' Let's plot the museum record minimum depth against the literature record for minimum
#'  depth of each species, to visualize how well they correlate.
plot(Lit.MinDepth.m ~ Mus95.MinDepth, data =Oligo_data)
abline(lm(Lit.MinDepth.m ~ Mus95.MinDepth, data =Oligo_data))
#' Not much to gain by exploring this further, it looks like!
#'
#' Now let's plot the museum record maximum depth against the literature record for max depth
#' of each species, to visualize how well they correlate.
plot(Lit.MaxDepth.m ~ Mus95.MaxDepth, data =Oligo_data)
abline(lm(Lit.MaxDepth.m ~ Mus95.MaxDepth, data =Oligo_data))
summary(lm(Lit.MaxDepth.m ~ Mus95.MaxDepth, data =Oligo_data)) 
#' Looks like they correlate well!
#'
#' Let's put a correlation statistic on it
cor.test(~Lit.MaxDepth.m + Mus95.MaxDepth, data = Oligo_data, method="spearman")
# p-value = 2.1e-05
#rho 
#0.8434845 
#'
#'
#' Looks like they're pretty strongly correlated, but we know that there are some
#' differences. Let's perform a phylogenetic paired t-test to see if the differences 
#' between the two maximum depth datasets are statistically significant.
#'
#' Combine the two columns of data into a new data frame 
dat.max_musmax <- cbind(Oligo_data[17], Oligo_data[23])
#'
#' Now perform the phylo paired t-test
maxdepth.ttest <- phyl.pairedttest(tree = Oligo_tree, x1=dat.max_musmax)
summary(maxdepth.ttest)
#' Let's pull out just the p-value
maxdepth.ttest$P.dbar
#[1] 0.8997011
# Looks like the differences are not statistically significant.
#'
#'
#'
#'
#'
######################### Character mapping and ancestral state reconstruction #####
#'
#'
#'
###### Ancestral state reconstruction of continuous characters
#'
#### Maximum length in millimeters 
#' First let's visualize the distribution and ancestral state reconstruction on the
#' phylogeny of Oligocottinae
max.length <- Oligo_data$Max_Length.mm
names(max.length) <- row.names(Oligo_data)
contMap(Oligo_tree,max.length)
title("ASR Max Length (mm)")
# Let's get the precise estimates of the ancestral state
max.length.ASR <- fastAnc(Oligo_tree,max.length, CI =T)
plotTree(Oligo_tree)
nodelabels() # Looks like node "19" is the MRCA of Oligocottinae
max.length.ASR$ace["19"] 
#19 
#132.492 
#' Looks like the maximum likelihood estimate of the standard length of the most
#' recent common ancestor (MRCA) of the subfamily Oligocottinae is 132.49 mm. 
#' Let's find the 95% confidence interval
max.length.ASR$CI95[2,]
#[1]  82.57441 182.40953
#' With 95% confidence, the most recent common ancestor of Oligocottinae
#' was between 82.57 and 182.41 mm in standard length.
#' 
#' 
# Maximum Depth in meters for 95% of museum collections
#' First let's visualize the distribution and ancestral state reconstruction on the
#' phylogeny of Oligocottinae (note however that the color scheme is different from
#' the corresponding figure in the manuscript, however the data and results are
#' the same).
max.depth <- Oligo_data$Mus95.MaxDepth
names(max.depth) <- row.names(Oligo_data)
contMap(Oligo_tree,max.depth)
title("ASR Max Depth (m)")
# Now let's get the precise estimates of the ancestral state for the MRCA
max.depth.ASR <- fastAnc(Oligo_tree,max.depth, CI =T)
max.depth.ASR$ace["19"] #MRCA Oligocottinae
#19 
#22.7685 
# Let's look at the ML estimate for the max depth of some other important hypothetical
# most recent common ancestors
max.depth.ASR$ace["25"] #MRCA Oligocottini
#25 
#16.4464
max.depth.ASR$ace["33"] #MRCA Leiocottus lineage
#33 
#16.14131
#
#' Looks like the maximum likelihood estimate of the maximum common depth of the most
#' recent common ancestor (MRCA) of the subfamily Oligocottinae is ~23 m. 
#' Let's find the 95% confidence interval
max.depth.ASR$CI95[2,]
#[1]  2.029943 43.507062
#' With 95% confidence, the maximum depth at which the MRCA of Oligocottinae
#' occured was between ~2 and 44 m.
#'
#'
#'
# Minimum depth in meters for 95% of museum collections
min.depth <- Oligo_data$Mus95.MinDepth
names(min.depth) <- row.names(Oligo_data)
contMap(Oligo_tree,min.depth)
title("ASR Min Depth (m)")
# Now let's get the precise estimates of the ancestral state for the MRCA
min.depth.ASR <- fastAnc(Oligo_tree,min.depth, CI =T)
min.depth.ASR$ace["19"]
#19 
#0.5698106  
#' Looks like the maximum likelihood estimate of the minimum common depth of the most
#' recent common ancestor (MRCA) of the subfamily Oligocottinae is ~23 m. 
#' Let's find the 95% confidence interval
min.depth.ASR$CI95[2,]
#[1] -0.3681254  1.5077467
#' With 95% confidence, the maximum depth at which the MRCA of Oligocottinae
#' occured was between -0.3681254 and 1.5077467 m. Now, we know that a negative depth
#' is not biologially plausible for these species, so really we're looking at a minimum
#' depth that is between 0 and 1.50 meters.
#'
#'
#'
##### Visualize inferred evolutionary history and state uncertainty in ASR
#
# First we'll reset the plot area settings
dev.off()
#' For max depth, min depth, and max length, let's plot a phenogram to show the 
#' inferred evolutionary hisotry of each trait, and plot the 95% confidence interval
#' for the state estimate at each location along the phylogeny.The position of each
#' node and tip on the y-axis corresponds to the state estimate.
# For max depth
fancyTree(Oligo_tree,x=max.depth,type="phenogram95",spread.labels=T,fsize=0.5,ylab="Maximum Depth",xlab="relative time since root")
#
# For min depth
fancyTree(Oligo_tree,x=min.depth,type="phenogram95",spread.labels=T,fsize=0.5,ylab="Min Depth (M)",xlab="relative time since root")
#
# For max length
fancyTree( Oligo_tree,x=max.length,type="phenogram95",spread.labels=T,fsize=0.5,ylab="Maximum Length",xlab="relative time since root")
#
#'
#'
#'
############################ Body shape analysis #################################
#'
#'
#'
##### Number of significant axes
library(vegan)
#
#Read in procustes-aligned landmark coordinates from MophoJ
Procrustes.coords <- read.csv(file = "MorphoJcoords.csv", header=T, row.names =1)
#
#' We'll use a base PCA function to get the coordinates in the proper format
Oligo_PCA <- prcomp(Procrustes.coords)
#' Now we'll use the broken stick method to determine the number of significant PC 
#' axes.
screeplot(Oligo_PCA, bstick = T, type = "lines")
#' Looks like the first two are significant
#' If we want to convince ourselves that these PC scores are the same as the ones produced
#' in the principal component analysis conducted in morphoJ, we can visually 
#' compare the values. The sign (+/-) is arbitrary and may differ between the two, 
#' but the values are the same.
Oligo_PCA$x #PC scores we just generated
Oligo_data[1:16]  # PC sc
#Now let's see how much of the total variance the two significant PC axes accound for.
summary(Oligo_PCA)
#                           PC1     PC2
#Proportion of Variance 0.51466 0.19014
#Cumulative Proportion  0.51466 0.70480
#'
#'
############ Phylomorphospace of the significant PC axes
#
# PC1 v PC2
dat.pms21 <- cbind(Oligo_data[1], Oligo_data[2])
phylomorphospace(Oligo_tree, dat.pms21)
#
#'
#'
#'
################################ Depth correlation analysis ################
# The following code was adapted from a script written by Dr. Samantha Price, which is
# available on the tree thinkers website: 
# http://treethinkers.org/tutorials/continuous-traits/
dev.off()
# Let's start by having a look at max depth plotted against max length
plot(Mus95.MaxDepth ~ Max_Length.mm, data =Oligo_data)
# Seems plausible that the two could be related. Let's check for correlation.
cor.test(~Max_Length.mm + Mus95.MaxDepth, data = Oligo_data, method="spearman")
#p-value = 0.0103
#rho 
#0.6036022
#' Looks like there is evidence of correlation, but these data are not independant! 
#' There is covariance due to phylogenetic relationships among the taxa. Let's use
#' a more sophisticated test that can take into account the expected covariance 
#' due to phylogenetic relationships.
#' 
####### Phylogenetic generalized least squares (PGLS)
####### PGLS with Pagel's lambda
# Fit PGLS model of max depth vs. max length. Pagel's lambda estimated by ML
# initial run with Pagel's lambda free to vary returned lamda > 1, so fix lambda at 1.
fit.Pagel.fix <- gls(Mus95.MaxDepth ~ Max_Length.mm , correlation=
                       corPagel(value= 1, fixed = T,  phy=Oligo_tree), data =Oligo_data)
summary(fit.Pagel.fix)
# Doesn't look like there is a significant relationship
# p = 0.2816
# Plot variables with regression line
plot(Mus95.MaxDepth ~ Max_Length.mm, data =Oligo_data)
abline(fit.Pagel.fix, col = "cadetblue1")
#Now we can do some basic tests to check our standard regression assumptions
#Plot fitted vs residuals
plot(fit.Pagel.fix, resid(., type="n")~fitted(.), main="Normalized Residuals v Fitted Values",
     abline=c(0,0))
# Check for departures of normally-distrubuted residuals
res <- resid(fit.Pagel.fix, type="n")
qqnorm(res)
qqline(res)
### Model Testing of Length v Depth
#PGLS assuming trait evolution is pure Brownian motion
result.pureBM<-gls(Mus95.MaxDepth ~ Max_Length.mm, data = Oligo_data, correlation=corBrownian(phy=Oligo_tree),method="ML")
#PGLS assuming trait evolution is being drawn to a single adaptive optimum in an OU model
result.Martins<-gls(Mus95.MaxDepth ~ Max_Length.mm, data = Oligo_data, correlation=corMartins(value=1, phy=Oligo_tree, fixed=FALSE),method="ML")
#PGLS assuming trait evolution varies due to late/early burst
result.Blomberg<-gls(Mus95.MaxDepth ~ Max_Length.mm, data = Oligo_data, correlation=corBlomberg(value=0.1, phy=Oligo_tree, fixed=F),method="ML")
summary(result.pureBM)
summary(result.Martins)
summary(result.Blomberg)    
# None of the alternative models are significant
#'
#'
#' Let's look at the relationship of depth with some of our other traits:
#'
#' Let's consider our binary characters, "Presence of scales" and "Presence of enlarged genital
#' papilla" and whether the average maximum depth is significanlty different for species with or
#' without these traits.
#'
#' 
#' We are not including the traits "Parental Care," "Spermatozoon morphology," or
#' "copulation" as they contain missing data, which is often not handled well using
#' these procedures and would severly limit the interpreation of any results thereof.
#' Instead, reproductive characters are represented solely by the presence/absence of
#' an enlarged genital papilla, a character for which we have data in all species. 
#'
########## Depth ~ Squamation
squam <- as.factor(Oligo_data$Squamation) #we need to properly format the vector of scale data
names(squam) <- row.names(Oligo_data[21]) #more formatting, this time to associate the species names with the presence/absence data
#
ddepth <- Oligo_data[23] #grab the vector of depth data 
scales.anova <- aov.phylo(ddepth~squam, Oligo_tree, nsim = 1000) #here's our ANOVA, with 1000 simulations to test for significance
summary(scales.anova)
#'
#' Looks like the average maximum depth of species with squamation is not significantly different
#' from the average maximum depth of species without squamation.
#' 
########### Depth ~ Papilla
papilla <- as.factor(Oligo_data$Papilla) #We'll format the data as before
names(papilla) <- row.names(Oligo_data[21])
#
papilla.anova <- aov.phylo(ddepth~papilla, Oligo_tree, nsim = 1000)
summary(papilla.anova)
#'
#' Looks like the average maximum depth of species with enlarged genital papillae is not significantly
#' different from the average maximum depth of species without enlarged genital papillae.
#'
#'
####### surface analysis
library(surface)
#
# We'll need to format our phylogeny for surface
Oligo_tree_surf <- nameNodes(Oligo_tree)
#
##### Let's run surface with the two significant PC axes: PC1 and PC2
PC12_data <- as.data.frame(cbind(as.numeric(Oligo_data$PC1), as.numeric(Oligo_data$PC2)), row.names = row.names(Oligo_data))
colnames(PC12_data) <- c("PC1","PC2")
#make sure the names match b/w phylo and data matrix
name.check(Oligo_tree_surf, PC12_data)
Oligo_surfPC12 <- runSurface(tree = Oligo_tree_surf, dat =PC12_data)
surfaceSummary(Oligo_surfPC12$bwd)
#Surface summary output
Oligo_surf_sum_PC12 <- surfaceSummary(Oligo_surfPC12$bwd)
Oligo_surf_kk_PC12 <- length(Oligo_surfPC12$bwd)
# Let's visualize the results on the phylogeny
surfaceTreePlot(Oligo_tree_surf, Oligo_surfPC12$bwd[[Oligo_surf_kk_PC12]],
                labelshifts = T)
# Looks like the tribe Oligocottini and the Blennicottus subgenus have distinct
# adaptive optima
# Let's visualize where the inferred optima lie in morphospace
surfaceTraitPlot(PC12_data, Oligo_surfPC12$bwd[[Oligo_surf_kk_PC12]])
# Shows the adaptive optima in the regions of morphospae occupied by the Blennicottus
# lineage, the Oligocottus lineage, and then everyone else.
#'
#'
#'
#'
################# Partial least squares (PLS)
library(geomorph)
dev.off() #reset the plot settings
class(Procrustes.coords) #make sure we're dealing with a data.frame
#' Now we need to take our dataset of species averaged procrustes-aligned landmark
#' coordinates and change the format to take full advantage of the PLS function
#' in geomorph.
array.Procrustes.coords <- arrayspecs(Procrustes.coords, p = 13, k = 2)
depthminmax <- Oligo_data[c(23,24)] #make a data frame for our depth data
depthminmax <- depthminmax[row.names(Procrustes.coords),] #sort the rows so that they're in the same order as the coordinate data
dimnames(array.Procrustes.coords)[3][[1]] == row.names(Procrustes.coords) #make sure the rownames aka taxa names are the same
# Now we're ready to execute the two-block PLS function
summary(oligo.pls <-two.b.pls(array.Procrustes.coords,depthminmax,iter=10000))
plot(oligo.pls)
#' Looks like there is a not-quite significant relationship between head/mouth shape +
#' body depth and the depth range of each species, such that shallower-ranging species
#' have deeper bodies and smaller mouths.



